@@ -42,7 +42,7 @@ def get_web3(uri, chain_id=None, hrp=None, timeout=10, modules=None):
             web3 = Web3(provider(uri), chain_id=chain_id, hrp=hrp, modules=modules)
             if web3.isConnected():
                 break
-            t.sleep(2)
+            t.sleep(1)
 
     return web3
 
@@ -106,14 +106,14 @@ def contract_call(func):
     return wrapper
 
 
-def contract_transaction(func_id=None):
+def contract_transaction(func_id=None, default_txn=None):
     """ todo: 增加注释
     """
 
     def out_wrapper(func):
 
         @functools.wraps(func)
-        def wrapper(self, *args, txn=None, private_key=None, **kwargs):
+        def wrapper(self, *args, txn=default_txn, private_key=None, **kwargs):
             # 预填充from地址，避免预估gas时地址相关检验不通过
             account = self.web3.platon.account.from_key(private_key, hrp=self.web3.hrp) if private_key else self.default_account
             if not txn:
